@@ -1,14 +1,14 @@
 // -*- C++ -*-
 
-/* 
+/*
  * GChemPaint library
- * document.h 
+ * document.h
  *
- * Copyright (C) 2001-2011 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2012 Jean Bréfort <jean.brefort@normalesup.org>
  *
- * This program is free software; you can redistribute it and/or 
- * modify it under the terms of the GNU General Public License as 
- * published by the Free Software Foundation; either version 2 of the
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 3 of the
  * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
@@ -107,6 +107,7 @@ Empties a document and reinitialize it.
 @return the gcp::View associated with the document.
 */
 	View* GetView () {return m_pView;}
+	View const*GetView () const {return m_pView;}
 /*!
 Saves the current file.
 */
@@ -356,7 +357,7 @@ objecst as a molecule or a reaction, it will reurn it's alignment value, otherwi
 /*!
 @return the gcp::Window displaying the document if any.
 */
-	Window *GetWindow () {return m_Window;}
+	gcu::Window *GetWindow ();
 /*!
 @return GtkWindow displaying the document if any.
 */
@@ -445,11 +446,16 @@ but a different meaning from the standard residue.
 @param molecule a molecule with a pseudo atom which describes the structure
 of the residue.
 
-
 @return the new Residue on success or NULL.
 */
 	gcu::Residue *CreateResidue (char const *name, char const *symbol, gcu::Molecule *molecule);
 
+/*!
+@return the set of objects created during the current operation (such as
+pasting data). This is used to properly update links such as which bonds
+correspond to which atoms as the pasted objects might have the same id than
+already existing objects.
+*/
 	std::set <std::string> &GetNewObjects () {return m_NewObjects;}
 
 private:
@@ -644,6 +650,19 @@ Sets the new current text font size for the document.
 @return the current brackets font size as a reference.
 */
 GCU_PROP (int, BracketsFontSize)
+
+/*!\fn SetUseAtomColors(bool val)
+@param val whether to use symbolic colors for the atomic symbols.
+
+When set, atomic symbols will be displayed using the symbolic colors for the
+element (when the color is not white, i.e. hydrogen symbol will always be black).
+*/
+/*!\fn GetUseAtomColors()
+@return whether to use symbolic colors for the atomic symbols.
+*/
+/*!\fn GetRefUseAtomColors()
+@return whether to use symbolic colors for the atomic symbols as a reference.
+*/
 GCU_PROP (bool, UseAtomColors)
 };
 
